==> grib2io-0.9.1.tar.gz: grib2io-0.9.1/grib2io/tables/section4_discipline3.py <==
table_4_2_3_0  = {
'0':['Scaled Radiance','Numeric','SRAD'],
'1':['Scaled Albedo','Numeric','SALBEDO'],
'2':['Scaled Brightness Temperature','Numeric','SBTMP'],
'3':['Scaled Precipitable Water','Numeric','SPWAT'],
'4':['Scaled Lifted Index','Numeric','SLFTI'],
'5':['Scaled Cloud Top Pressure','Numeric','SCTPRES'],
'6':['Scaled Skin Temperature','Numeric','SSTMP'],
'7':['Cloud Mask','See Table 4.217','CLOUDM'],
'8':['Pixel scene type','See Table 4.218','PIXST'],
'9':['Fire Detection Indicator','See Table 4.223','FIREDI'],
'10-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
table_4_2_3_1  = {
'0':['Estimated Precipitation','kg m-2','ESTP'],
'1':['Instantaneous Rain Rate','kg m-2 s-1','IRRATE'],
'2':['Cloud Top Height','m','CTOPH'],
'3':['Cloud Top Height Quality Indicator','Code table 4.219','CTOPHQI'],
'4':['Estimated u-Component of Wind','m s-1','ESTUGRD'],
'5':['Estimated v-Component of Wind','m s-1','ESTVGRD'],
'6':['Number Of Pixels Used','Numeric','NPIXU'],
'7':['Solar Zenith Angle','°','SOLZA'],
'8':['Relative Azimuth Angle','°','RAZA'],
'9':['Reflectance in 0.6 Micron Channel','%','RFL06'],
'10':['Reflectance in 0.8 Micron Channel','%','RFL08'],
'11':['Reflectance in 1.6 Micron Channel','%','RFL16'],
'12':['Reflectance in 3.9 Micron Channel','%','RFL39'],
'13':['Atmospheric Divergence','s-1','ATMDIV'],
'14':['Cloudy Brightness Temperature','K','CBTMP'],
'15':['Clear Sky Brightness Temperature','K','CSBTMP'],
'16':['Cloudy Radiance (with respect to wave number)','W m-1 sr-1','CLDRAD'],
'17':['Clear Sky Radiance (with respect to wave number)','W m-1 sr-1','CSKYRAD'],
'18':['Reserved','unknown','unknown'],
'19':['Wind Speed','m s-1','WINDS'],
'20':['Aerosol Optical Thickness at 0.635 µm','unknown','AOT06'],
'21':['Aerosol Optical Thickness at 0.810 µm','unknown','AOT08'],
'22':['Aerosol Optical Thickness at 1.640 µm','unknown','AOT16'],
'23':['Angstrom Coefficient','unknown','ANGCOE'],
'24-26':['Reserved','unknown','unknown'],
'27':['Bidirectional Reflecance Factor','Numeric','BRFLF'],
'28':['Brightness Temperature','K','SPBRT'],
'29':['Scaled Radiance','Numeric','SCRAD'],
'30-97':['Reserved','unknown','unknown'],
'98':['Correlation coefficient between MPE rain rates  for the co-located IR data and the microwave data rain rates','Numeric','CCMPEMRR'],
'99':['Standard deviation between MPE rain rates  for the co-located IR data and the microwave data rain rates','Numeric','SDMPEMRR'],
'100-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'192':['Scatterometer Estimated U Wind Component','m s-1','USCT'],
'193':['Scatterometer Estimated V Wind Component','m s-1','VSCT'],
'194':['Scatterometer Wind Quality','unknown','SWQI'],
'255':['Missing','unknown','unknown'],
}
table_4_2_3_2  = {
'0':['Clear Sky Probability','%','CSKPROB'],
'1':['Cloud Top Temperature','K','CTOPTMP'],
'2':['Cloud Top Pressure','Pa','CTOPRES'],
'3':['Cloud Type','See Table 4.218','CLDTYPE'],
'4':['Cloud Phase','See Table 4.218','CLDPHAS'],
'5':['Cloud Optical Depth','Numeric','CLDODEP'],
'6':['Cloud Particle Effective Radius','m','CLDPER'],
'7':['Cloud Liquid Water Path','kg m-2','CLDLWP'],
'8':['Cloud Ice Water Path','kg m-2','CLDIWP'],
'9':['Cloud Albedo','Numeric','CLDALB'],
'10':['Cloud Emissivity','Numeric','CLDEMISS'],
'11':['Effective Absorption Optical Depth Ratio','Numeric','EAODR'],
'12-29':['Reserved','unknown','unknown'],
'30':['Measurement cost','Numeric','MEACST'],
'41-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
table_4_2_3_3  = {
'0':['Probability of Encountering Marginal Visual Flight Rules Conditions','%','PBMVFRC'],
'1':['Probability of Encountering Low Instrument Flight Rules Conditions','%','PBLIFRC'],
'2':['Probability of Encountering Instrument Flight Rules Conditions','%','PBINFRC'],
'3-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
table_4_2_3_4  = {
'0':['Volcanic Ash Probability','%','VOLAPROB'],
'1':['Volcanic Ash Cloud Top Temperature','K','VOLACDTT'],
'2':['Volcanic Ash Cloud Top Pressure','Pa','VOLACDTP'],
'3':['Volcanic Ash Cloud Top Height','m','VOLACDTH'],
'4':['Volcanic Ash Cloud Emissity','Numeric','VOLACDEM'],
'5':['Volcanic Ash Effective Absorption Depth Ratio','Numeric','VOLAEADR'],
'6':['Volcanic Ash Cloud Optical Depth','Numeric','VOLACDOD'],
'7':['Volcanic Ash Column Density','kg m-2','VOLACDEN'],
'8':['Volcanic Ash Particle Effective Radius','m','VOLAPER'],
'9-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
table_4_2_3_5  = {
'0':['Interface Sea-Surface Temperature','K','ISSTMP'],
'1':['Skin Sea-Surface Temperature','K','SKSSTMP'],
'2':['Sub-Skin Sea-Surface Temperature','K','SSKSSTMP'],
'3':['Foundation Sea-Surface Temperature','K','FDNSSTMP'],
'4':['Estimated bias between Sea-Surface Temperature and Standard','K','EBSSTSTD'],
'5':['Estimated bias Standard Deviation between Sea-Surface Temperature and Standard','K','EBSDSSTS'],
'6-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
table_4_2_3_6  = {
'0':['Global Solar Irradiance','W m-2','GSOLIRR'],
'1':['Global Solar Exposure','J m-2','GSOLEXP'],
'2':['Direct Solar Irradiance','W m-2','DIRSOLIR'],
'3':['Direct Solar Exposure','J m-2','DIRSOLEX'],
'4':['Diffuse Solar Irradiance','W m-2','DIFSOLIR'],
'5':['Diffuse Solar Exposure','J m-2','DIFSOLEX'],
'6-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
table_4_2_3_192  = {
'0':['Simulated Brightness Temperature for GOES 12, Channel 2','K','SBT122'],
'1':['Simulated Brightness Temperature for GOES 12, Channel 3','K','SBT123'],
'2':['Simulated Brightness Temperature for GOES 12, Channel 4','K','SBT124'],
'3':['Simulated Brightness Temperature for GOES 12, Channel 6','K','SBT126'],
'4':['Simulated Brightness Counts for GOES 12, Channel 3','Byte','SBC123'],
'5':['Simulated Brightness Counts for GOES 12, Channel 4','Byte','SBC124'],
'6':['Simulated Brightness Temperature for GOES 11, Channel 2','K','SBT112'],
'7':['Simulated Brightness Temperature for GOES 11, Channel 3','K','SBT113'],
'8':['Simulated Brightness Temperature for GOES 11, Channel 4','K','SBT114'],
'9':['Simulated Brightness Temperature for GOES 11, Channel 5','K','SBT115'],
'10':['Simulated Brightness Temperature for AMSRE on Aqua, Channel 9','K','AMSRE9'],
'11':['Simulated Brightness Temperature for AMSRE on Aqua, Channel 10','K','AMSRE10'],
'12':['Simulated Brightness Temperature for AMSRE on Aqua, Channel 11','K','AMSRE11'],
'13':['Simulated Brightness Temperature for AMSRE on Aqua, Channel 12','K','AMSRE12'],
'14':['Simulated Reflectance Factor for ABI GOES-16, Band-1','unknown','SRFA161'],
'15':['Simulated Reflectance Factor for ABI GOES-16, Band-2','unknown','SRFA162'],
'16':['Simulated Reflectance Factor for ABI GOES-16, Band-3','unknown','SRFA163'],
'17':['Simulated Reflectance Factor for ABI GOES-16, Band-4','unknown','SRFA164'],
'18':['Simulated Reflectance Factor for ABI GOES-16, Band-5','unknown','SRFA165'],
'19':['Simulated Reflectance Factor for ABI GOES-16, Band-6','unknown','SRFA166'],
'20':['Simulated Brightness Temperature for ABI GOES-16, Band-7','K','SBTA167'],
'21':['Simulated Brightness Temperature for ABI GOES-16, Band-8','K','SBTA168'],
'22':['Simulated Brightness Temperature for ABI GOES-16, Band-9','K','SBTA169'],
'23':['Simulated Brightness Temperature for ABI GOES-16, Band-10','K','SBTA1610'],
'24':['Simulated Brightness Temperature for ABI GOES-16, Band-11','K','SBTA1611'],
'25':['Simulated Brightness Temperature for ABI GOES-16, Band-12','K','SBTA1612'],
'26':['Simulated Brightness Temperature for ABI GOES-16, Band-13','K','SBTA1613'],
'27':['Simulated Brightness Temperature for ABI GOES-16, Band-14','K','SBTA1614'],
'28':['Simulated Brightness Temperature for ABI GOES-16, Band-15','K','SBTA1615'],
'29':['Simulated Brightness Temperature for ABI GOES-16, Band-16','K','SBTA1616'],
'30':['Simulated Reflectance Factor for ABI GOES-17, Band-1','unknown','SRFA171'],
'31':['Simulated Reflectance Factor for ABI GOES-17, Band-2','unknown','SRFA172'],
'32':['Simulated Reflectance Factor for ABI GOES-17, Band-3','unknown','SRFA173'],
'33':['Simulated Reflectance Factor for ABI GOES-17, Band-4','unknown','SRFA174'],
'34':['Simulated Reflectance Factor for ABI GOES-17, Band-5','unknown','SRFA175'],
'35':['Simulated Reflectance Factor for ABI GOES-17, Band-6','unknown','SRFA176'],
'36':['Simulated Brightness Temperature for ABI GOES-17, Band-7','K','SBTA177'],
'37':['Simulated Brightness Temperature for ABI GOES-17, Band-8','K','SBTA178'],
'38':['Simulated Brightness Temperature for ABI GOES-17, Band-9','K','SBTA179'],
'39':['Simulated Brightness Temperature for ABI GOES-17, Band-10','K','SBTA1710'],
'40':['Simulated Brightness Temperature for ABI GOES-17, Band-11','K','SBTA1711'],
'41':['Simulated Brightness Temperature for ABI GOES-17, Band-12','K','SBTA1712'],
'42':['Simulated Brightness Temperature for ABI GOES-17, Band-13','K','SBTA1713'],
'43':['Simulated Brightness Temperature for ABI GOES-17, Band-14','K','SBTA1714'],
'44':['Simulated Brightness Temperature for ABI GOES-17, Band-15','K','SBTA1715'],
'45':['Simulated Brightness Temperature for ABI GOES-17, Band-16','K','SBTA1716'],
'46':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-1','unknown','SRFAGR1'],
'47':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-2','unknown','SRFAGR2'],
'48':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-3','unknown','SRFAGR3'],
'49':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-4','unknown','SRFAGR4'],
'50':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-5','unknown','SRFAGR5'],
'51':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-6','unknown','SRFAGR6'],
'52':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-7','unknown','SBTAGR7'],
'53':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-8','unknown','SBTAGR8'],
'54':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-9','unknown','SBTAGR9'],
'55':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-10','unknown','SBTAGR10'],
'56':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-11','unknown','SBTAGR11'],
'57':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-12','unknown','SBTAGR12'],
'58':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-13','unknown','SBTAGR13'],
'59':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-14','unknown','SBTAGR14'],
'60':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-15','unknown','SBTAGR15'],
'61':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-16','unknown','SBTAGR16'],
'62':['Simulated Brightness Temperature for SSMIS-F17, Channel 15','K','SSMS1715'],
'63':['Simulated Brightness Temperature for SSMIS-F17, Channel 16','K','SSMS1716'],
'64':['Simulated Brightness Temperature for SSMIS-F17, Channel 17','K','SSMS1717'],
'65':['Simulated Brightness Temperature for SSMIS-F17, Channel 18','K','SSMS1718'],
'66':['Simulated Brightness Temperature for Himawari-8, Band-7','K','SBTAHI7'],
'67':['Simulated Brightness Temperature for Himawari-8, Band-8','K','SBTAHI8'],
'68':['Simulated Brightness Temperature for Himawari-8, Band-9','K','SBTAHI9'],
'69':['Simulated Brightness Temperature for Himawari-8, Band-10','K','SBTAHI10'],
'70':['Simulated Brightness Temperature for Himawari-8, Band-11','K','SBTAHI11'],
'71':['Simulated Brightness Temperature for Himawari-8, Band-12','K','SBTAHI12'],
'72':['Simulated Brightness Temperature for Himawari-8, Band-13','K','SBTAHI13'],
'73':['Simulated Brightness Temperature for Himawari-8, Band-14','K','SBTAHI14'],
'74':['Simulated Brightness Temperature for Himawari-8, Band-15','K','SBTAHI15'],
'75':['Simulated Brightness Temperature for Himawari-8, Band-16','K','SBTAHI16'],
'76-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}

==> grib2io-1.0.3.tar.gz: grib2io-1.0.3/grib2io/tables/section4_discipline3.py <==
table_4_2_3_0  = {
'0':['Scaled Radiance','Numeric','SRAD'],
'1':['Scaled Albedo','Numeric','SALBEDO'],
'2':['Scaled Brightness Temperature','Numeric','SBTMP'],
'3':['Scaled Precipitable Water','Numeric','SPWAT'],
'4':['Scaled Lifted Index','Numeric','SLFTI'],
'5':['Scaled Cloud Top Pressure','Numeric','SCTPRES'],
'6':['Scaled Skin Temperature','Numeric','SSTMP'],
'7':['Cloud Mask','See Table 4.217','CLOUDM'],
'8':['Pixel scene type','See Table 4.218','PIXST'],
'9':['Fire Detection Indicator','See Table 4.223','FIREDI'],
'10-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
table_4_2_3_1  = {
'0':['Estimated Precipitation','kg m-2','ESTP'],
'1':['Instantaneous Rain Rate','kg m-2 s-1','IRRATE'],
'2':['Cloud Top Height','m','CTOPH'],
'3':['Cloud Top Height Quality Indicator','Code table 4.219','CTOPHQI'],
'4':['Estimated u-Component of Wind','m s-1','ESTUGRD'],
'5':['Estimated v-Component of Wind','m s-1','ESTVGRD'],
'6':['Number Of Pixels Used','Numeric','NPIXU'],
'7':['Solar Zenith Angle','°','SOLZA'],
'8':['Relative Azimuth Angle','°','RAZA'],
'9':['Reflectance in 0.6 Micron Channel','%','RFL06'],
'10':['Reflectance in 0.8 Micron Channel','%','RFL08'],
'11':['Reflectance in 1.6 Micron Channel','%','RFL16'],
'12':['Reflectance in 3.9 Micron Channel','%','RFL39'],
'13':['Atmospheric Divergence','s-1','ATMDIV'],
'14':['Cloudy Brightness Temperature','K','CBTMP'],
'15':['Clear Sky Brightness Temperature','K','CSBTMP'],
'16':['Cloudy Radiance (with respect to wave number)','W m-1 sr-1','CLDRAD'],
'17':['Clear Sky Radiance (with respect to wave number)','W m-1 sr-1','CSKYRAD'],
'18':['Reserved','unknown','unknown'],
'19':['Wind Speed','m s-1','WINDS'],
'20':['Aerosol Optical Thickness at 0.635 µm','unknown','AOT06'],
'21':['Aerosol Optical Thickness at 0.810 µm','unknown','AOT08'],
'22':['Aerosol Optical Thickness at 1.640 µm','unknown','AOT16'],
'23':['Angstrom Coefficient','unknown','ANGCOE'],
'24-26':['Reserved','unknown','unknown'],
'27':['Bidirectional Reflecance Factor','Numeric','BRFLF'],
'28':['Brightness Temperature','K','SPBRT'],
'29':['Scaled Radiance','Numeric','SCRAD'],
'30-97':['Reserved','unknown','unknown'],
'98':['Correlation coefficient between MPE rain rates  for the co-located IR data and the microwave data rain rates','Numeric','CCMPEMRR'],
'99':['Standard deviation between MPE rain rates  for the co-located IR data and the microwave data rain rates','Numeric','SDMPEMRR'],
'100-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'192':['Scatterometer Estimated U Wind Component','m s-1','USCT'],
'193':['Scatterometer Estimated V Wind Component','m s-1','VSCT'],
'194':['Scatterometer Wind Quality','unknown','SWQI'],
'255':['Missing','unknown','unknown'],
}
table_4_2_3_2  = {
'0':['Clear Sky Probability','%','CSKPROB'],
'1':['Cloud Top Temperature','K','CTOPTMP'],
'2':['Cloud Top Pressure','Pa','CTOPRES'],
'3':['Cloud Type','See Table 4.218','CLDTYPE'],
'4':['Cloud Phase','See Table 4.218','CLDPHAS'],
'5':['Cloud Optical Depth','Numeric','CLDODEP'],
'6':['Cloud Particle Effective Radius','m','CLDPER'],
'7':['Cloud Liquid Water Path','kg m-2','CLDLWP'],
'8':['Cloud Ice Water Path','kg m-2','CLDIWP'],
'9':['Cloud Albedo','Numeric','CLDALB'],
'10':['Cloud Emissivity','Numeric','CLDEMISS'],
'11':['Effective Absorption Optical Depth Ratio','Numeric','EAODR'],
'12-29':['Reserved','unknown','unknown'],
'30':['Measurement cost','Numeric','MEACST'],
'41-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
table_4_2_3_3  = {
'0':['Probability of Encountering Marginal Visual Flight Rules Conditions','%','PBMVFRC'],
'1':['Probability of Encountering Low Instrument Flight Rules Conditions','%','PBLIFRC'],
'2':['Probability of Encountering Instrument Flight Rules Conditions','%','PBINFRC'],
'3-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
table_4_2_3_4  = {
'0':['Volcanic Ash Probability','%','VOLAPROB'],
'1':['Volcanic Ash Cloud Top Temperature','K','VOLACDTT'],
'2':['Volcanic Ash Cloud Top Pressure','Pa','VOLACDTP'],
'3':['Volcanic Ash Cloud Top Height','m','VOLACDTH'],
'4':['Volcanic Ash Cloud Emissity','Numeric','VOLACDEM'],
'5':['Volcanic Ash Effective Absorption Depth Ratio','Numeric','VOLAEADR'],
'6':['Volcanic Ash Cloud Optical Depth','Numeric','VOLACDOD'],
'7':['Volcanic Ash Column Density','kg m-2','VOLACDEN'],
'8':['Volcanic Ash Particle Effective Radius','m','VOLAPER'],
'9-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
table_4_2_3_5  = {
'0':['Interface Sea-Surface Temperature','K','ISSTMP'],
'1':['Skin Sea-Surface Temperature','K','SKSSTMP'],
'2':['Sub-Skin Sea-Surface Temperature','K','SSKSSTMP'],
'3':['Foundation Sea-Surface Temperature','K','FDNSSTMP'],
'4':['Estimated bias between Sea-Surface Temperature and Standard','K','EBSSTSTD'],
'5':['Estimated bias Standard Deviation between Sea-Surface Temperature and Standard','K','EBSDSSTS'],
'6-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
table_4_2_3_6  = {
'0':['Global Solar Irradiance','W m-2','GSOLIRR'],
'1':['Global Solar Exposure','J m-2','GSOLEXP'],
'2':['Direct Solar Irradiance','W m-2','DIRSOLIR'],
'3':['Direct Solar Exposure','J m-2','DIRSOLEX'],
'4':['Diffuse Solar Irradiance','W m-2','DIFSOLIR'],
'5':['Diffuse Solar Exposure','J m-2','DIFSOLEX'],
'6-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
table_4_2_3_192  = {
'0':['Simulated Brightness Temperature for GOES 12, Channel 2','K','SBT122'],
'1':['Simulated Brightness Temperature for GOES 12, Channel 3','K','SBT123'],
'2':['Simulated Brightness Temperature for GOES 12, Channel 4','K','SBT124'],
'3':['Simulated Brightness Temperature for GOES 12, Channel 6','K','SBT126'],
'4':['Simulated Brightness Counts for GOES 12, Channel 3','Byte','SBC123'],
'5':['Simulated Brightness Counts for GOES 12, Channel 4','Byte','SBC124'],
'6':['Simulated Brightness Temperature for GOES 11, Channel 2','K','SBT112'],
'7':['Simulated Brightness Temperature for GOES 11, Channel 3','K','SBT113'],
'8':['Simulated Brightness Temperature for GOES 11, Channel 4','K','SBT114'],
'9':['Simulated Brightness Temperature for GOES 11, Channel 5','K','SBT115'],
'10':['Simulated Brightness Temperature for AMSRE on Aqua, Channel 9','K','AMSRE9'],
'11':['Simulated Brightness Temperature for AMSRE on Aqua, Channel 10','K','AMSRE10'],
'12':['Simulated Brightness Temperature for AMSRE on Aqua, Channel 11','K','AMSRE11'],
'13':['Simulated Brightness Temperature for AMSRE on Aqua, Channel 12','K','AMSRE12'],
'14':['Simulated Reflectance Factor for ABI GOES-16, Band-1','unknown','SRFA161'],
'15':['Simulated Reflectance Factor for ABI GOES-16, Band-2','unknown','SRFA162'],
'16':['Simulated Reflectance Factor for ABI GOES-16, Band-3','unknown','SRFA163'],
'17':['Simulated Reflectance Factor for ABI GOES-16, Band-4','unknown','SRFA164'],
'18':['Simulated Reflectance Factor for ABI GOES-16, Band-5','unknown','SRFA165'],
'19':['Simulated Reflectance Factor for ABI GOES-16, Band-6','unknown','SRFA166'],
'20':['Simulated Brightness Temperature for ABI GOES-16, Band-7','K','SBTA167'],
'21':['Simulated Brightness Temperature for ABI GOES-16, Band-8','K','SBTA168'],
'22':['Simulated Brightness Temperature for ABI GOES-16, Band-9','K','SBTA169'],
'23':['Simulated Brightness Temperature for ABI GOES-16, Band-10','K','SBTA1610'],
'24':['Simulated Brightness Temperature for ABI GOES-16, Band-11','K','SBTA1611'],
'25':['Simulated Brightness Temperature for ABI GOES-16, Band-12','K','SBTA1612'],
'26':['Simulated Brightness Temperature for ABI GOES-16, Band-13','K','SBTA1613'],
'27':['Simulated Brightness Temperature for ABI GOES-16, Band-14','K','SBTA1614'],
'28':['Simulated Brightness Temperature for ABI GOES-16, Band-15','K','SBTA1615'],
'29':['Simulated Brightness Temperature for ABI GOES-16, Band-16','K','SBTA1616'],
'30':['Simulated Reflectance Factor for ABI GOES-17, Band-1','unknown','SRFA171'],
'31':['Simulated Reflectance Factor for ABI GOES-17, Band-2','unknown','SRFA172'],
'32':['Simulated Reflectance Factor for ABI GOES-17, Band-3','unknown','SRFA173'],
'33':['Simulated Reflectance Factor for ABI GOES-17, Band-4','unknown','SRFA174'],
'34':['Simulated Reflectance Factor for ABI GOES-17, Band-5','unknown','SRFA175'],
'35':['Simulated Reflectance Factor for ABI GOES-17, Band-6','unknown','SRFA176'],
'36':['Simulated Brightness Temperature for ABI GOES-17, Band-7','K','SBTA177'],
'37':['Simulated Brightness Temperature for ABI GOES-17, Band-8','K','SBTA178'],
'38':['Simulated Brightness Temperature for ABI GOES-17, Band-9','K','SBTA179'],
'39':['Simulated Brightness Temperature for ABI GOES-17, Band-10','K','SBTA1710'],
'40':['Simulated Brightness Temperature for ABI GOES-17, Band-11','K','SBTA1711'],
'41':['Simulated Brightness Temperature for ABI GOES-17, Band-12','K','SBTA1712'],
'42':['Simulated Brightness Temperature for ABI GOES-17, Band-13','K','SBTA1713'],
'43':['Simulated Brightness Temperature for ABI GOES-17, Band-14','K','SBTA1714'],
'44':['Simulated Brightness Temperature for ABI GOES-17, Band-15','K','SBTA1715'],
'45':['Simulated Brightness Temperature for ABI GOES-17, Band-16','K','SBTA1716'],
'46':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-1','unknown','SRFAGR1'],
'47':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-2','unknown','SRFAGR2'],
'48':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-3','unknown','SRFAGR3'],
'49':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-4','unknown','SRFAGR4'],
'50':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-5','unknown','SRFAGR5'],
'51':['Simulated Reflectance Factor for nadir ABI GOES-R, Band-6','unknown','SRFAGR6'],
'52':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-7','unknown','SBTAGR7'],
'53':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-8','unknown','SBTAGR8'],
'54':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-9','unknown','SBTAGR9'],
'55':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-10','unknown','SBTAGR10'],
'56':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-11','unknown','SBTAGR11'],
'57':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-12','unknown','SBTAGR12'],
'58':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-13','unknown','SBTAGR13'],
'59':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-14','unknown','SBTAGR14'],
'60':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-15','unknown','SBTAGR15'],
'61':['Simulated Brightness Temperature for nadir ABI GOES-R, Band-16','unknown','SBTAGR16'],
'62':['Simulated Brightness Temperature for SSMIS-F17, Channel 15','K','SSMS1715'],
'63':['Simulated Brightness Temperature for SSMIS-F17, Channel 16','K','SSMS1716'],
'64':['Simulated Brightness Temperature for SSMIS-F17, Channel 17','K','SSMS1717'],
'65':['Simulated Brightness Temperature for SSMIS-F17, Channel 18','K','SSMS1718'],
'66':['Simulated Brightness Temperature for Himawari-8, Band-7','K','SBTAHI7'],
'67':['Simulated Brightness Temperature for Himawari-8, Band-8','K','SBTAHI8'],
'68':['Simulated Brightness Temperature for Himawari-8, Band-9','K','SBTAHI9'],
'69':['Simulated Brightness Temperature for Himawari-8, Band-10','K','SBTAHI10'],
'70':['Simulated Brightness Temperature for Himawari-8, Band-11','K','SBTAHI11'],
'71':['Simulated Brightness Temperature for Himawari-8, Band-12','K','SBTAHI12'],
'72':['Simulated Brightness Temperature for Himawari-8, Band-13','K','SBTAHI13'],
'73':['Simulated Brightness Temperature for Himawari-8, Band-14','K','SBTAHI14'],
'74':['Simulated Brightness Temperature for Himawari-8, Band-15','K','SBTAHI15'],
'75':['Simulated Brightness Temperature for Himawari-8, Band-16','K','SBTAHI16'],
'76':['Simulated Brightness Temperature for ABI GOES-18, Band-7','K','SBTA187'],
'77':['Simulated Brightness Temperature for ABI GOES-18, Band-8','K','SBTA188'],
'78':['Simulated Brightness Temperature for ABI GOES-18, Band-9','K','SBTA189'],
'79':['Simulated Brightness Temperature for ABI GOES-18, Band-10','K','SBTA1810'],
'80':['Simulated Brightness Temperature for ABI GOES-18, Band-11','K','SBTA1811'],
'81':['Simulated Brightness Temperature for ABI GOES-18, Band-12','K','SBTA1812'],
'82':['Simulated Brightness Temperature for ABI GOES-18, Band-13','K','SBTA1813'],
'83':['Simulated Brightness Temperature for ABI GOES-18, Band-14','K','SBTA1814'],
'84':['Simulated Brightness Temperature for ABI GOES-18, Band-15','K','SBTA1815'],
'85':['Simulated Brightness Temperature for ABI GOES-18, Band-16','K','SBTA1816'],
'86-191':['Reserved','unknown','unknown'],
'192-254':['Reserved for Local Use','unknown','unknown'],
'255':['Missing','unknown','unknown'],
}
